/**
 * Copyright (c) 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.api.command;

import java.util.Iterator;
import java.util.ServiceLoader;
import java.util.logging.Logger;

import org.ow2.petals.cli.api.exception.DuplicatedCommandException;
import org.ow2.petals.cli.api.shell.Shell;

public class CommandRegistration {

    private static final Logger LOG = Logger.getLogger(CommandRegistration.class.getName());

    private CommandRegistration() {
        // Reduce visibility of the constructor because it's an utility calss
    }

    /**
     * Registers commands declared on the classpath into a shell. Commands are
     * declared through the service provider {@link Command}.
     * 
     * @param shell
     *            The shell in which commands will be registered.
     */
    public static void registers(final Shell shell) {
        final ServiceLoader<Command> commandLoader = ServiceLoader.load(Command.class);
        final Iterator<Command> commandsIterator = commandLoader.iterator();
        while (commandsIterator.hasNext()) {
            final Command command = commandsIterator.next();
            try {
                command.setShell(shell);
                shell.registersCommand(command);
                LOG.fine("Command '" + command.getName() + "' registered.");
            } catch (final DuplicatedCommandException e) {
                // Command already registered
                LOG.severe("Trying to register a command already registered ('" + command.getName()
                        + "'). Ignored.");
            } catch (final IllegalArgumentException e) {
                // It's a bug
                LOG.severe("Trying to register a null command. Ignored.");
            }
        }
    }

}
